import {
  margin,
  width,
  height,
  svg,
  xScale,
  yScale,
  drawXAxis,
  drawYAxis,
  dropdown,
  myColor,
  yMinInput,
  yMaxInput,
} from './support.js';

import { tooltip } from './events.js';

var data;
var lines = [
  'win_gap',
  'top_five_gap',
  'top_ten_gap',
  'first_last_gap',
];
var yMax = 100;
var yMin = 0;

//updating based on the dropdown
dropdown.on('change', function () {
  if (d3.select(this).property('value') == 'all') {
    lines = [
      'win_gap',
      'top_five_gap',
      'top_ten_gap',
      'first_last_gap',
    ];
  } else {
    lines = [d3.select(this).property('value')];
  }
  console.log(lines);
  render();
});

yMaxInput.on('change', function () {
  yMax = d3.select(this).property('value');
  //console.log(yMax);
  render();
});

yMinInput.on('change', function () {
  yMin = d3.select(this).property('value');
  //console.log(yMax);
  render();
});

//draw lines

function drawLines(curLine) {
  //values
  const xValue = (d) => d.Year;
  const yValue = (d) => d[curLine];
  const popUpValue = (d) => {
    /// seconds conversion from: https://www.geeksforgeeks.org/how-to-convert-seconds-to-time-string-format-hhmmss-using-javascript/
    const given_seconds = d;
    if (given_seconds == 0) {
      return 'missing data';
    } else {
      const hours = Math.floor(given_seconds / 3600);
      const minutes = Math.floor(
        (given_seconds - hours * 3600) / 60,
      );
      const seconds =
        given_seconds - hours * 3600 - minutes * 60;

      const timeString =
        hours.toString().padStart(2, '0') +
        ':' +
        minutes.toString().padStart(2, '0') +
        ':' +
        seconds.toString().padStart(2, '0');

      return timeString;
    }
  };

  // Draw lines
  const line = d3
    .line()
    .x((d) => xScale(xValue(d)))
    .y((d) => yScale(yValue(d) / 60))
    .curve(d3.curveLinear);

  svg
    .append('path')
    .datum(data)
    .attr('id', 'trendline')
    .attr('fill', 'none')
    .attr('stroke', myColor(curLine))
    .attr('stroke-width', 2)
    .attr('d', line);

  // Draw dots
  svg
    .selectAll('[empty]')
    .data(data)
    .join('circle')
    .attr('cx', (d) => xScale(xValue(d)))
    .attr('cy', (d) => yScale(yValue(d) / 60))
    .attr('r', 4)
    .attr('fill', myColor(curLine))
    .attr('id', (d) => d.Country)
    .attr('class', 'circle')
    .on('mouseover', function (event, d) {
      const tooltip = d3.select('#tooltip');
      tooltip
        .style('visibility', 'visible')
        .html(
          `<strong>${xValue(d)}</strong><br/> Winner: ${d['Winner']}  <br/>Winning Time: ${popUpValue(d['win_time'])} <br/>Country: ${d.Country} <br/> Time Gap: ${popUpValue(yValue(d))}`,
        )
        .style('left', event.pageX + 10 + 'px')
        .style('top', event.pageY - 28 + 'px');
    })
    .on('mouseout', function () {
      d3.select('#tooltip').style('visibility', 'hidden');
    });
}

//render fuction
function render() {
  //Draw Axis
  drawXAxis(data);
  drawYAxis(data, yMax, yMin);

  //clear the graph
  svg.selectAll(`#trendline`).remove();
  svg.selectAll(`circle`).remove();

  //loop through the array of things to draw:

  lines.forEach((line) => drawLines(line));

  //Draw some clever boxes to clip the data from going off the page
  svg
    .append('rect')
    .attr('x', 0)
    .attr('y', 0)
    .attr('width', width)
    .attr('height', margin.top - 4)
    .attr('fill', 'white');
}

const winDataUrl =
  'https://raw.githubusercontent.com/georgeb3ck/dataviz/main/supercleanTDF.csv';

Promise.all([d3.csv(winDataUrl)]).then(([rawdata]) => {
  console.log(rawdata);
  data = rawdata;
  render();
});
