//***SET UP***
export const margin = {
  top: 60,
  right: 20,
  bottom: 40,
  left: 70,
};

export const width = 1200;
export const height = 500;
export const innerWidth =
  width - margin.left - margin.right;
export const innerHeight =
  height - margin.top - margin.bottom;

export const svg = d3
  .select('#my_dataviz')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

export const dropdown = d3.select('#gapSelect');
export const yMinInput = d3.select('#yMin');
export const yMaxInput = d3.select('#yMax');

const gapOptions = [
  'all',
  'win_gap',
  'top_five_gap',
  'top_ten_gap',
  'first_last_gap',
];

dropdown
  .selectAll('[empty]')
  .data(gapOptions)
  .join('option')
  .attr('value', (d) => d)
  .text((d) => d);

//***Scales***
var yearMin = 1903;
var yearMax = 2023;
export const xScale = d3
  .scaleLinear()
  .range([margin.left, innerWidth]);

export const yScale = d3
  .scaleLinear()
  .range([innerHeight, margin.top]);

export var myColor = d3
  .scaleOrdinal()
  .domain([
    'win_gap',
    'top_five_gap',
    'top_ten_gap',
    'first_last_gap',
  ])
  .range(['#66c2a5', '#fc8d62', '#8da0cb', '#e78ac3']);

//**AXES***
const yAxis = svg
  .append('g')
  .attr('id', 'yaxis')
  .attr('transform', `translate(${margin.left},0)`);

const xAxis = svg
  .append('g')
  .attr('id', 'xaxis')
  .attr('transform', `translate(0,${innerHeight})`);

export function drawXAxis(data) {
  xScale.domain([yearMin, yearMax]);
  d3.select(`#xaxis`).call(
    d3
      .axisBottom(xScale)
      .ticks(10)
      .tickFormat((t) => String(t)),
  );
}

export function drawYAxis(data, min, max) {
  yScale.domain([max, min]);
  d3.select(`#yaxis`).call(d3.axisLeft(yScale));
}

//**LABELS**
svg
  .append('text')
  .text(`Years`)
  .attr('id', 'yearLabel')
  .attr('x', width / 2)
  .attr('y', height - margin.bottom)
  .style('text-anchor', 'middle');

svg
  .append('text')
  .text('Time Gap (Minutes)')
  .attr('transform', 'rotate(-90)')
  .attr('x', -height / 2)
  .attr('y', margin.left / 2 - 10);

//***legend***
const legend = svg
  .append('g')
  .attr('class', 'legend')
  .attr(
    'transform',
    `translate(${width - 250},${margin.top + 10})`,
  );

legend
  .append('rect')
  .attr('x', 0)
  .attr('y', 0)
  .attr('width', 10)
  .attr('height', 10)
  .attr('fill', '#66c2a5');

legend
  .append('text')
  .attr('x', 15)
  .attr('y', 10)
  .text('Gap from 1st to 2nd place');

legend
  .append('rect')
  .attr('x', 0)
  .attr('y', 20)
  .attr('width', 10)
  .attr('height', 10)
  .attr('fill', '#fc8d62');

legend
  .append('text')
  .attr('x', 15)
  .attr('y', 30)
  .text('Gap from 1st to 5th place');

legend
  .append('rect')
  .attr('x', 0)
  .attr('y', 40)
  .attr('width', 10)
  .attr('height', 10)

  .attr('fill', '#8da0cb');

legend
  .append('text')
  .attr('x', 15)
  .attr('y', 50)
  .text('Gap from 1st to 10th place');

legend
  .append('rect')
  .attr('x', 0)
  .attr('y', 60)
  .attr('width', 10)
  .attr('height', 10)

  .attr('fill', '#e78ac3');

legend
  .append('text')
  .attr('x', 15)
  .attr('y', 70)
  .text('Gap from 1st to last place');
